@@ -4,6 +4,8 @@ from typing import Optional, Tuple
 
 from yarl import URL
 
+from .url_utils import _check_uri, _check_uri_str
+
 
 class TagOption(enum.Enum):
     ALLOW = enum.auto()
@@ -131,7 +133,7 @@ class _ImageNameParser:
     def parse_remote(
         self, value: str, *, tag_option: TagOption = TagOption.DEFAULT
     ) -> RemoteImage:
-        if self.is_in_neuro_registry(value):
+        if value.startswith("image:") or value.startswith(f"{self._registry}/"):
             return self.parse_as_neuro_image(value, tag_option=tag_option)
         else:
             img = self.parse_as_local_image(value)
@@ -146,16 +148,22 @@ class _ImageNameParser:
                 name=name, tag=img.tag, registry=registry
             )
 
-    def is_in_neuro_registry(self, image: str) -> bool:
-        # not use URL here because URL("ubuntu:v1") is parsed as scheme=ubuntu path=v1
-        return image.startswith("image:") or image.startswith(f"{self._registry}/")
-
     def convert_to_neuro_image(self, image: LocalImage) -> RemoteImage:
         assert self._registry is not None
+        owner = self._default_user
+        name = image.name
+        if image.name.startswith(f"{self._registry}/"):
+            path = image.name[len(self._registry) :].lstrip("/")
+            if path:
+                owner, _, name = path.partition("/")
+                if not name:
+                    owner = self._default_user
+                    name = path
+
         return RemoteImage.new_neuro_image(
-            name=image.name,
+            name=name,
             tag=image.tag,
-            owner=self._default_user,
+            owner=owner,
             cluster_name=self._default_cluster,
             registry=self._registry,
         )
@@ -163,18 +171,6 @@ class _ImageNameParser:
     def convert_to_local_image(self, image: RemoteImage) -> LocalImage:
         return LocalImage(name=image.name, tag=image.tag)
 
-    def normalize(self, image: str) -> str:
-        try:
-            if self.is_in_neuro_registry(image):
-                remote_image = self.parse_as_neuro_image(image)
-                image_normalized = str(remote_image)
-            else:
-                local_image = self.parse_as_local_image(image)
-                image_normalized = str(local_image)
-        except ValueError:
-            image_normalized = image
-        return image_normalized
-
     def has_tag(self, image: str) -> bool:
         prefix = "image:"
         if image.startswith(prefix):
@@ -193,7 +189,7 @@ class _ImageNameParser:
             )
 
     def _parse_as_local_image(self, image: str) -> LocalImage:
-        if self.is_in_neuro_registry(image):
+        if image.startswith("image:"):
             raise ValueError("scheme 'image://' is not allowed for local images")
         name, tag = self._split_image_name(image, "latest")
         return LocalImage(name=name, tag=tag)
@@ -201,32 +197,30 @@ class _ImageNameParser:
     def _parse_as_neuro_image(
         self, image: str, default_tag: Optional[str]
     ) -> RemoteImage:
-        if not self.is_in_neuro_registry(image):
-            raise ValueError("scheme 'image://' is required for remote images")
-
-        if image.startswith(f"{self._registry}/"):
-            path = image[len(f"{self._registry}/") :]
-            image = f"image://{self._default_cluster}/{path}"
-
-        url = URL(image)
-
-        if url.scheme and url.scheme != "image":
-            # image with port in registry: `localhost:5000/owner/ubuntu:latest`
-            url = URL(f"//{url}")
-
-        if not url.scheme:
-            parts = url.path.split("/")
+        assert self._registry is not None
+        if image.startswith("image:"):
+            # Check string representation to detect also trailing "?" and "#".
+            _check_uri_str(image, "image")
+            url = URL(image)
+            if not url.scheme and url.path.startswith("image:"):
+                url = URL.build(
+                    scheme="image",
+                    host=self._default_cluster,
+                    path=f"/{self._default_user}/{url.path[len('image:') :]}",
+                )
+        elif image.startswith(f"{self._registry}/"):
             url = URL.build(
                 scheme="image",
-                host=parts[1],
-                path="/".join([""] + parts[2:]),
-                query=url.query,
+                host=self._default_cluster,
+                path=image[len(self._registry) :],
             )
+        else:
+            raise ValueError("scheme 'image:' is required for remote images")
 
-        self._check_allowed_uri_elements(url)
+        if not url.path or url.path == "/":
+            raise ValueError("no image name specified")
+        _check_uri(url)
 
-        assert self._registry is not None
-        registry = self._registry
         name, tag = self._split_image_name(url.path.lstrip("/"), default_tag)
         cluster_name = url.host or self._default_cluster
         if url.path.startswith("/"):
@@ -238,7 +232,7 @@ class _ImageNameParser:
         return RemoteImage.new_neuro_image(
             name=name,
             tag=tag,
-            registry=registry,
+            registry=self._registry,
             owner=owner,
             cluster_name=cluster_name,
         )
@@ -271,22 +265,6 @@ class _ImageNameParser:
             raise ValueError("invalid tag")
         return name, tag
 
-    def _check_allowed_uri_elements(self, url: URL) -> None:
-        if not url.path or url.path == "/":
-            raise ValueError("no image name specified")
-        if url.query:
-            raise ValueError(f"query is not allowed, found: '{url.query}'")
-        if url.fragment:
-            raise ValueError(f"fragment is not allowed, found: '{url.fragment}'")
-        if url.user:
-            raise ValueError(f"user is not allowed, found: '{url.user}'")
-        if url.password:
-            raise ValueError(f"password is not allowed, found: '{url.password}'")
-        if url.port and url.scheme == "image":
-            raise ValueError(
-                f"port is not allowed with 'image://' scheme, found: '{url.port}'"
-            )
-
 
 def _get_url_authority(url: URL) -> Optional[str]:
     if url.host is None:
