@@ -26,12 +26,12 @@ from .utils import ImageFormatter, URIFormatter, image_formatter
 
 
 COLORS = {
-    JobStatus.PENDING: "yellow",
+    JobStatus.PENDING: "cyan",
     JobStatus.RUNNING: "blue",
     JobStatus.SUCCEEDED: "green",
-    JobStatus.CANCELLED: "green",
+    JobStatus.CANCELLED: "yellow",
     JobStatus.FAILED: "red",
-    JobStatus.UNKNOWN: "yellow",
+    JobStatus.UNKNOWN: "bright_red",
 }
 
 
@@ -146,6 +146,18 @@ class JobStatusFormatter:
             lines.append(f"{bold('Secret files')}:")
             lines.extend(f"  {i}" for i in table(rows2))
 
+        if job_status.container.disk_volumes:
+            rows3 = [
+                (
+                    disk_volume.container_path,
+                    self._format_uri(disk_volume.disk_uri),
+                    "READONLY" if disk_volume.read_only else " ",
+                )
+                for disk_volume in job_status.container.disk_volumes
+            ]
+            lines.append(f"{bold('Disk volumes')}:")
+            lines.extend(f"  {i}" for i in table(rows3))
+
         if job_status.internal_hostname:
             add("Internal Hostname", job_status.internal_hostname)
         if job_status.internal_hostname_named:
