@@ -1,12 +1,11 @@
 import asyncio
 import contextlib
 import logging
-import re
 import shlex
 import sys
 import uuid
 import webbrowser
-from datetime import datetime, timedelta
+from datetime import datetime
 from typing import List, Optional, Sequence, Set, Tuple
 
 import async_timeout
@@ -59,13 +58,19 @@ from .formatters.jobs import (
     SimpleJobsFormatter,
     TabularJobsFormatter,
 )
-from .parse_utils import JobColumnInfo, get_default_columns, parse_columns
+from .parse_utils import (
+    JobColumnInfo,
+    get_default_columns,
+    parse_columns,
+    parse_timedelta,
+)
 from .root import Root
 from .utils import (
     NEURO_STEAL_CONFIG,
     AsyncExitStack,
     alias,
     argument,
+    calc_life_span,
     command,
     deprecated_quiet_option,
     group,
@@ -81,9 +86,6 @@ log = logging.getLogger(__name__)
 STORAGE_MOUNTPOINT = "/var/storage"
 
 DEFAULT_JOB_LIFE_SPAN = "1d"
-REGEX_TIME_DELTA = re.compile(
-    r"^((?P<d>\d+)d)?((?P<h>\d+)h)?((?P<m>\d+)m)?((?P<s>\d+)s)?$"
-)
 
 
 TTY_OPT = option(
@@ -208,7 +210,6 @@ def job() -> None:
     help=(
         "Mounts directory from vault into container. "
         "Use multiple options to mount more than one volume. "
-        "Use --volume=ALL to mount all accessible storage directories."
     ),
     secure=True,
 )
@@ -889,7 +890,6 @@ async def kill(root: Root, jobs: Sequence[str]) -> None:
     help=(
         "Mounts directory from vault into container. "
         "Use multiple options to mount more than one volume. "
-        "Use --volume=ALL to mount all accessible storage directories. "
         "See `neuro help secrets` for information about "
         "passing secrets as mounted files."
     ),
@@ -1149,16 +1149,19 @@ async def run_job(
     job_restart_policy = JobRestartPolicy(restart)
     log.debug(f"Job restart policy: {job_restart_policy}")
 
-    job_life_span = await calc_life_span(root.client, life_span)
+    job_life_span = await calc_life_span(
+        root.client, life_span, DEFAULT_JOB_LIFE_SPAN, "job"
+    )
     log.debug(f"Job run-time limit: {job_life_span}")
 
     if schedule_timeout is None:
         job_schedule_timeout = None
     else:
-        job_schedule_timeout = _parse_timedelta(schedule_timeout).total_seconds()
+        job_schedule_timeout = parse_timedelta(schedule_timeout).total_seconds()
     log.debug(f"Job schedule timeout: {job_schedule_timeout}")
 
-    env_dict, secret_env_dict = root.client.parse.env(env, env_file)
+    env_parse_result = root.client.parse.envs(env, env_file)
+    env_dict, secret_env_dict = env_parse_result.env, env_parse_result.secret_env
     real_cmd = _parse_cmd(cmd)
 
     log.debug(f'entrypoint="{entrypoint}"')
@@ -1181,7 +1184,10 @@ async def run_job(
         tpu_software_version=tpu_software_version,
     )
 
-    volumes, secret_files = root.client.parse.volumes(volume)
+    volume_parse_result = root.client.parse.volumes(volume)
+    volumes = list(volume_parse_result.volumes)
+    secret_files = volume_parse_result.secret_files
+    disk_volumes = volume_parse_result.disk_volumes
 
     if pass_config:
         env_name = NEURO_STEAL_CONFIG
@@ -1205,9 +1211,10 @@ async def run_job(
         http=HTTPPort(http, http_auth) if http else None,
         resources=resources,
         env=env_dict,
-        volumes=list(volumes),
+        volumes=volumes,
         secret_env=secret_env_dict,
-        secret_files=list(secret_files),
+        secret_files=secret_files,
+        disk_volumes=disk_volumes,
         tty=tty,
     )
 
@@ -1336,49 +1343,6 @@ async def calc_columns(
     return format
 
 
-async def calc_life_span(client: Client, value: Optional[str]) -> Optional[float]:
-    async def _calc_default_life_span(client: Client) -> timedelta:
-        config = await client.config.get_user_config()
-        section = config.get("job")
-        life_span = DEFAULT_JOB_LIFE_SPAN
-        if section is not None:
-            value = section.get("life-span")
-            if value is not None:
-                life_span = value
-        return _parse_timedelta(life_span)
-
-    delta = (
-        _parse_timedelta(value)
-        if value is not None
-        else await _calc_default_life_span(client)
-    )
-    seconds = delta.total_seconds()
-    if seconds == 0:
-        return None
-    assert seconds > 0
-    return seconds
-
-
-def _parse_timedelta(value: str) -> timedelta:
-    value = value.strip()
-    err = f"Could not parse time delta '{value}'"
-    if value == "":
-        raise click.UsageError(f"{err}: Empty string not allowed")
-    if value == "0":
-        return timedelta(0)
-    match = REGEX_TIME_DELTA.search(value)
-    if match is None:
-        raise click.UsageError(
-            f"{err}: Should be like '1d2h3m4s' (some parts may be missing)."
-        )
-    return timedelta(
-        days=int(match.group("d") or 0),
-        hours=int(match.group("h") or 0),
-        minutes=int(match.group("m") or 0),
-        seconds=int(match.group("s") or 0),
-    )
-
-
 def _parse_date(value: str) -> Optional[datetime]:
     if value:
         try:
