@@ -9,7 +9,6 @@ import re
 import shlex
 import shutil
 import sys
-import warnings
 from datetime import timedelta
 from typing import (
     Any,
@@ -474,7 +473,7 @@ async def resolve_job(
     return id_or_name
 
 
-SHARE_SCHEMES = ("storage", "image", "job", "blob", "role")
+SHARE_SCHEMES = ("storage", "image", "job", "blob", "role", "secret")
 
 
 def parse_resource_for_sharing(uri: str, root: Root) -> URL:
@@ -648,12 +647,11 @@ async def calc_life_span(
     )
     seconds = delta.total_seconds()
     if seconds == 0:
-        warnings.warn(
+        click.secho(
             "Zero job's life-span (--life-span=0) is deprecated "
             "and will be removed in the future neuro CLI release,"
             "use a positive value to avoid resource leakage",
-            DeprecationWarning,
-            stacklevel=2,
+            fg="yellow",
         )
         return None
     assert seconds > 0
