@@ -8,7 +8,16 @@ from contextlib import suppress
 from datetime import datetime, timedelta
 from pathlib import Path
 from time import sleep, time
-from typing import Any, AsyncIterator, Callable, Dict, Iterator, List, Tuple
+from typing import (
+    Any,
+    AsyncIterator,
+    Callable,
+    ContextManager,
+    Dict,
+    Iterator,
+    List,
+    Tuple,
+)
 from uuid import uuid4
 
 import aiodocker
@@ -1014,9 +1023,9 @@ def test_job_attach_tty(helper: Helper) -> None:
 
     expect = helper.pexpect(["job", "attach", job_id])
     expect.expect("========== Job is running in terminal mode =========")
-    expect.sendline("")  # prompt may be missing after the connection.
+    expect.sendline("\n")  # prompt may be missing after the connection.
     repl = REPLWrapper(expect, "# ", None)
-    ret = repl.run_command("echo abc")
+    ret = repl.run_command("echo abc\n")
     assert ret.strip() == "echo abc\r\r\nabc"
 
     helper.kill_job(job_id)
@@ -1129,3 +1138,35 @@ def test_job_working_dir(helper: Helper) -> None:
     helper.wait_job_change_state_from(job_id, JobStatus.PENDING)
     helper.wait_job_change_state_from(job_id, JobStatus.RUNNING)
     helper.assert_job_state(job_id, JobStatus.SUCCEEDED)
+
+
+@pytest.mark.e2e
+def test_job_disk_volume(
+    helper: Helper, disk_factory: Callable[[str], ContextManager[str]]
+) -> None:
+
+    with disk_factory("1G") as disk:
+        bash_script = 'echo "test data" > /mnt/disk/file && cat /mnt/disk/file'
+        command = f"bash -c '{bash_script}'"
+        captured = helper.run_cli(
+            [
+                "job",
+                "run",
+                "--life-span",
+                "1m",  # Avoid completed job to block disk from cleanup
+                "-v",
+                f"disk:{disk}:/mnt/disk:rw",
+                "--no-wait-start",
+                UBUNTU_IMAGE_NAME,
+                command,
+            ]
+        )
+
+        out = captured.out
+        match = re.match("Job ID: (.+)", out)
+        assert match is not None, captured
+        job_id = match.group(1)
+
+        helper.wait_job_change_state_from(job_id, JobStatus.PENDING)
+        helper.wait_job_change_state_from(job_id, JobStatus.RUNNING)
+        helper.assert_job_state(job_id, JobStatus.SUCCEEDED)
